%global with_html               0

# It seems like there's some kind of weird occasional error where a
# build (often aarch64 or ppc64) will fail in one of the Stix font
# tests with a huge RMS difference, but if you run the same build again,
# you won't get the same error. Unless someone can figure out what's
# going on, we just have to keep re-running the build until it doesn't
# happen.
%global run_tests               0

# the default backend; one of GTK3Agg GTK3Cairo MacOSX Qt4Agg Qt5Agg TkAgg
# WXAgg Agg Cairo PS PDF SVG
%global backend                 Qt5Agg

%if "%{backend}" == "TkAgg"
%global backend_subpackage tk
%else
    %if "%{backend}" == "Qt5Agg"
%global backend_subpackage qt5
    %else
      %if "%{backend}" == "WXAgg"
%global backend_subpackage wx
      %endif
    %endif
%endif

# https://fedorahosted.org/fpc/ticket/381
%global with_bundled_fonts      1

# Use the same directory of the main package for subpackage licence and docs
%global _docdir_fmt %{name}

#global rctag rc2

# Updated test images for new FreeType.
%global mpl_images_version 3.8.1

# The version of FreeType in this Fedora branch.
%global ftver 2.13.1

Name:           python-matplotlib
Version:        3.8.2
Release:        %mkrel 4
Summary:        Python 2D plotting library
Group:          Development/Python
# qt4_editor backend is MIT
License:        Python and MIT
URL:            https://matplotlib.org/
Source0:        https://github.com/matplotlib/matplotlib/archive/v%{version}%{?rctag}/matplotlib-%{version}%{?rctag}.tar.gz
Source1:        setup.cfg

# Fedora-specific patches; see:
# https://github.com/fedora-python/matplotlib/tree/fedora-patches
# Updated test images for new FreeType.
Source1000:     https://github.com/QuLogic/mpl-images/archive/v%{mpl_images_version}-with-freetype-%{ftver}/matplotlib-%{mpl_images_version}-with-freetype-%{ftver}.tar.gz
# Define location of matplotlibrc file
Patch1001:      0001-matplotlibrc-path-search-fix.patch 
# We don't need to use NumPy 1.25.
Patch1002:      0002-Unpin-NumPy-build-requirement.patch
# Increase tolerances for new FreeType everywhere:
Patch1003:      0003-Set-FreeType-version-to-%{ftver}-and-update-tolerances.patch

# https://github.com/matplotlib/matplotlib/pull/21190#issuecomment-1223271888
Patch0001:      0004-Use-old-stride_windows-implementation-on-32-bit-x86.patch
# https://github.com/matplotlib/matplotlib/pull/26502
Patch0002:      0005-TST-Increase-some-tolerances-for-non-x86-arches.patch

# Mageia patches
# Patch5000:      matplotlib-matplotlib-3.3.1-pyparsing-reqs.patch

BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  locales-en
BuildRequires:  freetype-devel
BuildRequires:  libpng-devel
BuildRequires:  qhull-devel
BuildRequires:  texlive
BuildRequires:  texlive-dist
BuildRequires:  x11-server-xvfb
BuildRequires:  zlib-devel
BuildRequires:  fonts-ttf-dejavu
BuildRequires:  python3-pip
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3dist(setuptools-scm)

%description
Matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. Matplotlib can be used in Python
scripts, the Python and IPython shell, web application servers, and
various graphical user interface toolkits.

Matplotlib tries to make easy things easy and hard things possible.
You can generate plots, histograms, power spectra, bar charts,
errorcharts, scatterplots, etc, with just a few lines of code.

%package -n python3-matplotlib-data
Summary:        Data used by python-matplotlib
BuildArch:      noarch
Group:          Development/Python
%if %{with_bundled_fonts}
Requires:       python3-matplotlib-data-fonts = %{version}-%{release}
%endif
%{?python_provide:%python_provide python3-matplotlib-data}

%description -n python3-matplotlib-data
%{summary}.

%if %{with_bundled_fonts}
%package -n python3-matplotlib-data-fonts
Summary:        Fonts used by python-matplotlib
# STIX and Computer Modern is OFL
# DejaVu is Bitstream Vera and Public Domain
License:        OFL and Bitstream Vera and Public Domain
BuildArch:      noarch
Requires:       python3-matplotlib-data = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-data-fonts}

%description -n python3-matplotlib-data-fonts
%{summary}.
%endif

%package -n     python3-matplotlib
%{?python_provide:%python_provide python3-matplotlib}
Summary:        Python 2D plotting library
Group:          Development/Python
BuildRequires:  python3-cairo
BuildRequires:  python3-certifi >= 2020.06.20
BuildRequires:  python3-cycler >= 0.10.0
BuildRequires:  python3-dateutil
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-gobject
BuildRequires:  python3-kiwisolver
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-pillow
BuildRequires:  python3-pyparsing
BuildRequires:  python3-pytz
BuildRequires:  python3-sphinx
Requires:       fonts-ttf-dejavu
# for dvipng
Requires:       texlive
Requires:       python3-matplotlib-data = %{version}-%{release}
Requires:       python3-cairo
Requires:       python3-cycler >= 0.10.0
Requires:       python3-dateutil
Requires:       python3-kiwisolver
Requires:       python3-matplotlib-%{?backend_subpackage}%{!?backend_subpackage:tk}%{?_isa} = %{version}-%{release}
%if %{run_tests}
BuildRequires:  python3-pytest
BuildRequires:  python3-pytest-rerunfailures
BuildRequires:  python3-pytest-timeout
BuildRequires:  python3-pytest-xdist
%endif
Requires:       python3-numpy
Recommends:     python3-pillow
Requires:       python3-pyparsing
%if !%{with_bundled_fonts}
Requires:       stix-math-fonts
%else
Provides:       bundled(stix-math-fonts)
%endif
%{?python_provide:%python_provide python3-matplotlib}

%description -n python3-matplotlib
Matplotlib is a Python 2D plotting library which produces publication
quality figures in a variety of hardcopy formats and interactive
environments across platforms. Matplotlib can be used in Python
scripts, the Python and IPython shell, web application servers, and
various graphical user interface toolkits.

Matplotlib tries to make easy things easy and hard things possible.
You can generate plots, histograms, power spectra, bar charts,
errorcharts, scatterplots, etc, with just a few lines of code.

%package -n     python3-matplotlib-qt5
Summary:        Qt5 backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3-qt5
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-qt5
%{?python_provide:%python_provide python3-matplotlib-qt5}

%description -n python3-matplotlib-qt5
%{summary}.

%package -n     python3-matplotlib-qt6
Summary:        Qt6 backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3-qt6
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-qt6
%{?python_provide:%python_provide python3-matplotlib-qt6}

%description -n python3-matplotlib-qt6
%{summary}.

%package -n     python3-matplotlib-gtk3
Summary:        GTK3 backend for python3-matplotlib
Group:          Development/Python
# This should be converted to typelib(Gtk) when supported
BuildRequires:  gtk3-devel
BuildRequires:  python3-gobject
Requires:       python3-gobject%{?_isa}
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-gtk3}

%description -n python3-matplotlib-gtk3
%{summary}.

%package -n     python3-matplotlib-tk
Summary:        Tk backend for python3-matplotlib
Group:          Development/Python
BuildRequires:  python3-tkinter
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-tkinter
%{?python_provide:%python_provide python3-matplotlib-tk}

%description -n python3-matplotlib-tk
%{summary}.

%package -n     python3-matplotlib-wx
Summary:        WX backend for python3-matplotlib
BuildRequires:  python3-wxpython4
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
Requires:       python3-wxpython4
%{?python_provide:%python_provide python3-matplotlib-wx}

%description -n python3-matplotlib-wx
%{summary}.

%package -n python3-matplotlib-doc
Summary:        Documentation files for python-matplotlib
%if %{with_html}
BuildRequires:  dvipng
BuildRequires:  graphviz
BuildRequires:  python3-sphinx
BuildRequires:  tex(latex)
BuildRequires:  tex-preview
BuildRequires:  js-jquery >= 3.2.1
BuildRequires:  xstatic-jquery-ui-common
Requires:       js-jquery >= 3.2.1
Requires:       xstatic-jquery-ui-common
%endif
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-doc}

%description -n python3-matplotlib-doc
%{summary}.

%package -n python3-matplotlib-test-data
Summary:        Test data for python3-matplotlib
Requires:       python3-matplotlib%{?_isa} = %{version}-%{release}
%{?python_provide:%python_provide python3-matplotlib-test-data}

%description -n python3-matplotlib-test-data
%{summary}.


%prep
%autosetup -n matplotlib-%{version} -N 
# Fedora-specific patches follow:
%autopatch -p1 -m 1000
# Updated test images for new FreeType.
gzip -dc %SOURCE1000 | tar xf - --transform='s~^mpl-images-%{mpl_images_version}-with-freetype-%{ftver}/~~'

# Copy mplsetup.cfg to the builddir
cp -p %{SOURCE1} mplsetup.cfg

# Backports or reported upstream
%autopatch -p1 -M 999


%generate_buildrequires
%pyproject_buildrequires -r


%build
%set_build_flags
export http_proxy=http://127.0.0.1/

MPLCONFIGDIR=$PWD %pyproject_wheel
%if %{with_html}
# Need to make built matplotlib libs available for the sphinx extensions:
pushd doc
    MPLCONFIGDIR=$PWD/.. \
    PYTHONPATH=`realpath ../build/lib.linux*` \
        %{__python3} make.py html
popd
%endif
# Ensure all example files are non-executable so that the -doc
# package doesn't drag in dependencies
find galleries -name '*.py' -exec chmod a-x '{}' \;

%install
export http_proxy=http://127.0.0.1/

MPLCONFIGDIR=$PWD %pyproject_install
chmod +x %{buildroot}%{python3_sitearch}/matplotlib/dates.py
mkdir -p %{buildroot}%{_sysconfdir} %{buildroot}%{_datadir}/matplotlib
mv %{buildroot}%{python3_sitearch}/matplotlib/mpl-data \
   %{buildroot}%{_datadir}/matplotlib
ln -s %{_datadir}/matplotlib/mpl-data %{buildroot}%{python3_sitearch}/matplotlib/mpl-data
%if !%{with_bundled_fonts}
rm -rf %{buildroot}%{_datadir}/matplotlib/mpl-data/fonts
%endif

%if %{run_tests}
%check
# These files confuse pytest, and we want to test the installed copy.
rm -rf build*/

export http_proxy=http://127.0.0.1/
# Skips:
#  * test_invisible_Line_rendering: Checks for "slowness" that often fails on a
#    heavily-loaded builder.
#  * wxagg is broken on ppc64le:
#    https://bugzilla.redhat.com/show_bug.cgi?id=1738752
MPLCONFIGDIR=$PWD \
MATPLOTLIBRC=%{buildroot}%{_datadir}/matplotlib/mpl-data/matplotlibrc \
PYTHONPATH=%{buildroot}%{python3_sitearch} \
PYTHONDONTWRITEBYTECODE=1 \
     xvfb-run -a -s "-screen 0 640x480x24" \
         %{__python3} tests.py -ra -n $(getconf _NPROCESSORS_ONLN) \
             -m 'not network' \
             -k 'not test_invisible_Line_rendering and not Qt5Agg'
# Run Qt5Agg tests separately to not conflict with Qt4 tests.
MPLCONFIGDIR=$PWD \
MATPLOTLIBRC=%{buildroot}%{_datadir}/matplotlib/mpl-data/matplotlibrc \
PYTHONPATH=%{buildroot}%{python3_sitearch} \
PYTHONDONTWRITEBYTECODE=1 \
     xvfb-run -a -s "-screen 0 640x480x24" \
         %{__python3} tests.py -ra -n $(getconf _NPROCESSORS_ONLN) \
             -m 'not network'
%endif

%files -n python3-matplotlib-data
%{_datadir}/matplotlib/mpl-data/
%if %{with_bundled_fonts}
%exclude %{_datadir}/matplotlib/mpl-data/fonts/
%endif

%if %{with_bundled_fonts}
%files -n python3-matplotlib-data-fonts
%{_datadir}/matplotlib/mpl-data/fonts/
%endif

%files -n python3-matplotlib-doc
%doc galleries/examples
%if %{with_html}
%doc doc/build/html/*
%endif

%files -n python3-matplotlib
%license LICENSE/
%doc README.md
%{python3_sitearch}/*dist-info
%{python3_sitearch}/matplotlib/
%dir %{python3_sitearch}/matplotlib/backends
%dir %{python3_sitearch}/matplotlib/backends/__pycache__
%exclude %{python3_sitearch}/matplotlib/tests/baseline_images/*
%{python3_sitearch}/mpl_toolkits/
%exclude %{python3_sitearch}/mpl_toolkits/*/tests/baseline_images/*
%{python3_sitearch}/pylab.py*
%{python3_sitearch}/__pycache__/*
%exclude %{python3_sitearch}/matplotlib/mpl-data
%if "%{backend}" == "Qt5Agg"
%exclude %{python3_sitearch}/matplotlib/backends/backend_qt5*.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5*
%endif
%exclude %{python3_sitearch}/matplotlib/backends/backend_gtk*.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_gtk*

%if "%{backend}" == "TkAgg"
%exclude %{python3_sitearch}/matplotlib/backends/_backend_tk.py
%exclude %{python3_sitearch}/matplotlib/backends/backend_tk*.py
%exclude %{python3_sitearch}/matplotlib/backends/tkagg.py
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_tk*.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/tkagg.*
%exclude %{python3_sitearch}/matplotlib/backends/_tkagg.*
%endif
%if "%{backend}" == "WXAgg"
%exclude %{python3_sitearch}/matplotlib/backends/backend_wx*
%exclude %{python3_sitearch}/matplotlib/backends/wx_compat.*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/backend_wx*
%exclude %{python3_sitearch}/matplotlib/backends/__pycache__/wx_compat.*
%endif

%files -n python3-matplotlib-test-data
%{python3_sitearch}/matplotlib/tests/baseline_images/
%{python3_sitearch}/mpl_toolkits/*/tests/baseline_images/


%files -n python3-matplotlib-qt5
%{python3_sitearch}/matplotlib/backends/backend_qt5.*
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5.*
%{python3_sitearch}/matplotlib/backends/backend_qt5agg.*
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_qt5agg.*


# This is handled by backend_qt*.py (no number), so the package exists only for
# the dependencies.
%files -n python3-matplotlib-qt6


%files -n python3-matplotlib-gtk3
%{python3_sitearch}/matplotlib/backends/backend_gtk*.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_gtk*

%files -n python3-matplotlib-tk
%{python3_sitearch}/matplotlib/backends/backend_tk*.py
%{python3_sitearch}/matplotlib/backends/_backend_tk.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_tk*.*
%{python3_sitearch}/matplotlib/backends/__pycache__/_backend_tk.*
%{python3_sitearch}/matplotlib/backends/_tkagg.*

%files -n python3-matplotlib-wx
%{python3_sitearch}/matplotlib/backends/backend_wx*.py
%{python3_sitearch}/matplotlib/backends/__pycache__/backend_wx*


%changelog
* Sat Jan 27 2024 daviddavid <daviddavid> 3.8.2-4.mga10
+ Revision: 2035316
- add Qt6 subpackage

* Mon Jan 01 2024 daviddavid <daviddavid> 3.8.2-3.mga10
+ Revision: 2024992
- fix owner of /matplotlib/backends/__pycache__/ dir

* Wed Dec 20 2023 joequant <joequant> 3.8.2-2.mga10
+ Revision: 2020534
- rebuild for py3.12
+ tv <tv>
- 3.8.2

* Fri Dec 08 2023 wally <wally> 3.6.2-3.mga10
+ Revision: 2015795
- rebuild for py3.12

* Tue Dec 06 2022 papoteur <papoteur> 3.6.2-2.mga9
+ Revision: 1918603
- fix for matplotlibrc location

* Mon Dec 05 2022 papoteur <papoteur> 3.6.2-1.mga9
+ Revision: 1917996
- new 3.6.2
+ neoclust <neoclust>
- New version 3.6.0

* Wed Apr 06 2022 umeabot <umeabot> 3.3.3-4.mga9
+ Revision: 1846075
- Mageia 9 Mass Rebuild

* Sun Feb 13 2022 tv <tv> 3.3.3-3.mga9
+ Revision: 1773776
- Rebuild for python-3.10

* Mon Mar 15 2021 wally <wally> 3.3.3-2.mga9
+ Revision: 1703635
- rebuild for python 3.9

* Sat Nov 21 2020 guillomovitch <guillomovitch> 3.3.3-1.mga8
+ Revision: 1648130
- new version 3.3.3

* Mon Sep 21 2020 wally <wally> 3.3.2-3.mga8
+ Revision: 1629378
- add symlink for mpl-data dir

* Mon Sep 21 2020 wally <wally> 3.3.2-2.mga8
+ Revision: 1629369
- drop non-working matplotlibrc location patch

* Thu Sep 17 2020 guillomovitch <guillomovitch> 3.3.2-1.mga8
+ Revision: 1627493
- new version 3.3.2

* Thu Sep 10 2020 guillomovitch <guillomovitch> 3.3.1-1.mga8
+ Revision: 1624293
- new version 3.3.1

* Wed Jul 22 2020 ovitters <ovitters> 3.2.2-3.mga8
+ Revision: 1608061
- rebuild for get rid of pythonegg requires

* Sun Jun 21 2020 wally <wally> 3.2.2-2.mga8
+ Revision: 1598231
- add patch to drop boolean deps for pyparsing

* Sun Jun 21 2020 wally <wally> 3.2.2-1.mga8
+ Revision: 1598214
- new version 3.2.2 (sync with Fedora where appropriate)

* Sun Feb 16 2020 umeabot <umeabot> 3.1.1-3.mga8
+ Revision: 1532145
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Sun Sep 15 2019 wally <wally> 3.1.1-2.mga8
+ Revision: 1441714
- rebuild for core/release

* Sun Sep 15 2019 wally <wally> 3.1.1-1.mga8
+ Revision: 1441592
- fix font requires (SILNET)
- new version 3.1.1 (synced with Fedora where appropriate)
- drop python2 and qt4 support
- disable freetype related tests as we have newer freetype than expected

* Mon Jan 07 2019 tv <tv> 2.2.2-4.mga7
+ Revision: 1350559
- rebuild with python 3.7
+ shlomif <shlomif>
- Rebuild for python3 3.7

* Sun Sep 23 2018 umeabot <umeabot> 2.2.2-2.mga7
+ Revision: 1300525
- Mageia 7 Mass Rebuild

* Mon Aug 06 2018 eatdirt <eatdirt> 2.2.2-1.mga7
+ Revision: 1248203
- Upgrade to version 2.2.2

* Sun Apr 29 2018 joequant <joequant> 2.1.0-8.mga7
+ Revision: 1223574
- fix requires for stix-math
- rebuild with new dependencies

* Thu Nov 23 2017 tv <tv> 2.1.0-6.mga7
+ Revision: 1178941
- rename python-matplotlib-doc -> python2-matplotlib-doc
- fix bogus deps on python-matplotlib%%{?_isa}
- fix python_provides usage & drop redondant requires/obsoletes

* Wed Nov 22 2017 tv <tv> 2.1.0-5.mga7
+ Revision: 1178700
- rebuild due to missing subpkgs

* Sat Nov 11 2017 joequant <joequant> 2.1.0-4.mga7
+ Revision: 1176862
- change to new python2 naming conventions

* Sun Oct 15 2017 joequant <joequant> 2.1.0-3.mga7
+ Revision: 1172133
+ rebuild (emptylog)

* Sun Oct 15 2017 joequant <joequant> 2.1.0-2.mga7
+ Revision: 1171897
- rebuild for arm

* Sat Oct 14 2017 joequant <joequant> 2.1.0-1.mga7
+ Revision: 1171719
- update to 2.1.0

* Fri Oct 13 2017 joequant <joequant> 2.0.2-1.mga7
+ Revision: 1171608
- upgrade to 2.0.2

* Sat Aug 05 2017 pterjan <pterjan> 1.5.1-9.mga7
+ Revision: 1135493
- Rebuild for python 3.6

* Wed Apr 19 2017 wally <wally> 1.5.1-8.mga6
+ Revision: 1096831
- fix python-matplotlib-gtk requires (don't pull python3 pkgs)

* Fri Apr 29 2016 philippem <philippem> 1.5.1-7.mga6
+ Revision: 1007673
- bump release to fix wrong groups
- fix wrong group
- fix wrong group
- clean spec, re enable wx

* Wed Apr 27 2016 philippem <philippem> 1.5.1-5.mga6
+ Revision: 1006977
- move requires from description to a better place

* Sun Apr 24 2016 joequant <joequant> 1.5.1-4.mga6
+ Revision: 1005820
- fix requires

* Sun Apr 24 2016 joequant <joequant> 1.5.1-3.mga6
+ Revision: 1005812
- rebuild without xvfb
- remove vfb for build
- add numpy devel
- upgrade to 1.5.1

* Tue Feb 16 2016 umeabot <umeabot> 1.4.3-7.mga6
+ Revision: 962242
- Mageia 6 Mass Rebuild

* Sat Nov 07 2015 joequant <joequant> 1.4.3-6.mga6
+ Revision: 898393
- rebuild with numpy 1.10

* Wed Oct 07 2015 tv <tv> 1.4.3-5.mga6
+ Revision: 886969
- rebuild for python 3.5
+ joequant <joequant>
- rebuild with tk 8.6
- switch recommends tk back to requires to avoid breaking default config

* Mon Jul 20 2015 joequant <joequant> 1.4.3-1.mga6
+ Revision: 855645
- upgrade to 1.4.3

* Mon Jul 20 2015 joequant <joequant> 1.4.0-12.mga6
+ Revision: 855641
- check backends to suggests

* Mon Jul 20 2015 joequant <joequant> 1.4.0-11.mga6
+ Revision: 855616
- check backend requires to suggests

* Mon Feb 02 2015 joequant <joequant> 1.4.0-10.mga5
+ Revision: 813086
- add vera fonts to python3 version

* Sun Feb 01 2015 joequant <joequant> 1.4.0-9.mga5
+ Revision: 812951
- add vera fonts

* Thu Dec 18 2014 joequant <joequant> 1.4.0-8.mga5
+ Revision: 803919
- include fedora patchs.  make it work without qt5

* Tue Dec 02 2014 philippem <philippem> 1.4.0-7.mga5
+ Revision: 800359
- remove wrong dependency on python-pyxml

* Fri Oct 31 2014 joequant <joequant> 1.4.0-6.mga5
+ Revision: 795013
- use tkagg as default and remove unneeded backends

* Wed Oct 15 2014 umeabot <umeabot> 1.4.0-5.mga5
+ Revision: 741344
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 1.4.0-4.mga5
+ Revision: 729021
- rebuild for missing pythoneggs deps
- auto convert _exclude_files_from_autoreq
+ umeabot <umeabot>
- Mageia 5 Mass Rebuild

* Sat Sep 13 2014 philippem <philippem> 1.4.0-2.mga5
+ Revision: 675153
- fixing requires and BR

* Tue Sep 09 2014 philippem <philippem> 1.4.0-1.mga5
+ Revision: 674450
- fixe file list, add missing BR
- matplotlib need python-qt5
- update to 1.4.0

* Sat May 31 2014 pterjan <pterjan> 1.3.1-3.mga5
+ Revision: 628782
- Rebuild for new Python

* Fri Apr 25 2014 philippem <philippem> 1.3.1-2.mga5
+ Revision: 618096
- fix missing BR on python3-numpy-devel

* Sun Mar 16 2014 philippem <philippem> 1.3.1-1.mga5
+ Revision: 604266
- Update to 1.3.1

* Sat Nov 02 2013 fwang <fwang> 1.3.0-7.mga4
+ Revision: 548949
- filter correctly
- add requires

* Tue Oct 22 2013 umeabot <umeabot> 1.3.0-6.mga4
+ Revision: 543865
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 1.3.0-5.mga4
+ Revision: 498899
- Rebuild to add different pythonegg provides for python 2 and 3

* Wed Oct 02 2013 philippem <philippem> 1.3.0-4.mga4
+ Revision: 490539
+ rebuild (emptylog)

* Wed Sep 11 2013 joequant <joequant> 1.3.0-3.mga4
+ Revision: 477699
- add pyparsing which is required by matplotlib

* Sat Sep 07 2013 philippem <philippem> 1.3.0-2.mga4
+ Revision: 475676
- add matplotlib_UnicodeDecodeError.patch to fix mga#11128
- add requires on matplotlib-qt4 to fix mga#11131

* Wed Aug 28 2013 philippem <philippem> 1.3.0-1.mga4
+ Revision: 472699
- drop tk patch (upstream solved build issue differently)
- obsolete emf and fltk backends no longer provided upstream
- review file list
- disable build html doc
- disable build html doc
- Try to build without xvfb-run to see if it solve the dbus problem
- update to 1.3.0

* Thu Jul 04 2013 philippem <philippem> 1.2.0-4.mga4
+ Revision: 450088
- add Python 3

* Mon Jun 03 2013 fwang <fwang> 1.2.0-3.mga4
+ Revision: 436071
- rebuild for new libpng

* Sun Jan 13 2013 umeabot <umeabot> 1.2.0-2.mga3
+ Revision: 379123
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 23 2012 philippem <philippem> 1.2.0-1.mga3
+ Revision: 334342
- Update to 1.2.0

* Sun Oct 07 2012 philippem <philippem> 1.1.1-1.mga3
+ Revision: 303208
- Update to 1.1.1

* Fri Oct 21 2011 philippem <philippem> 1.1.0-1.mga2
+ Revision: 157235
- Update to 1.1.0

* Tue Sep 20 2011 fwang <fwang> 1.0.1-4.mga2
+ Revision: 145920
- fix build with latest libpng
- rebuild for new libpng
- br agg
- add debian patch to fix tkinter version detection
- sync with fedora package
- rebuild for new tcl

* Mon Apr 25 2011 grenoya <grenoya> 1.0.1-2.mga1
+ Revision: 90209
- increase release
- remove python-matplotlib-qt subpackage

* Sun Apr 24 2011 grenoya <grenoya> 1.0.1-1.mga1
+ Revision: 90115
- remove python-qt from buildrequires
- imported package python-matplotlib


* Fri Jan 07 2011 Lev Givon <lev@mandriva.org> 1.0.1-1mdv2011.0
+ Revision: 629185
- Update to 1.0.1.

* Thu Nov 04 2010 Paulo Andrade <pcpa@mandriva.com.br> 1.0.0-6mdv2011.0
+ Revision: 593527
+ rebuild (emptylog)

* Tue Nov 02 2010 Michael Scherer <misc@mandriva.org> 1.0.0-5mdv2011.0
+ Revision: 592431
- rebuild for python 2.7

  + Andrey Borzenkov <arvidjaar@mandriva.org>
    - rebuild for new python 2.7

  + Thierry Vignaud <tv@mandriva.org>
    - make doc subpackage noarch

* Tue Sep 07 2010 Lev Givon <lev@mandriva.org> 1.0.0-2mdv2011.0
+ Revision: 576692
- Bump release to force rebuild.

* Mon Jul 19 2010 Lev Givon <lev@mandriva.org> 1.0.0-1mdv2011.0
+ Revision: 555007
- Update to 1.0.0.

* Mon May 31 2010 Lev Givon <lev@mandriva.org> 0.99.3-1mdv2010.1
+ Revision: 546714
- Update to 0.99.3.

* Sun May 02 2010 Lev Givon <lev@mandriva.org> 0.99.1.2-4mdv2010.1
+ Revision: 541674
- Make main package require installation of gtk backend (#59044).

* Sat Apr 10 2010 Lev Givon <lev@mandriva.org> 0.99.1.2-3mdv2010.1
+ Revision: 533535
- Put docs in a separate package (#58679).

* Sun Jan 10 2010 Lev Givon <lev@mandriva.org> 0.99.1.2-2mdv2010.1
+ Revision: 488922
- Spin off backends with special installation dependencies
  to separate packages (#50278).

* Fri Dec 18 2009 Lev Givon <lev@mandriva.org> 0.99.1.2-1mdv2010.1
+ Revision: 479862
- Update to 0.99.1.2.

* Mon Oct 12 2009 Funda Wang <fwang@mandriva.org> 0.99.1-4mdv2010.0
+ Revision: 456749
- rebuild

* Wed Oct 07 2009 Lev Givon <lev@mandriva.org> 0.99.1-3mdv2010.0
+ Revision: 455814
- Require python-qt, python-qt4.
  Rebuild against new python-qt4.

* Wed Sep 23 2009 Lev Givon <lev@mandriva.org> 0.99.1-2mdv2010.0
+ Revision: 447968
- Use updated tarball that does not contain a spurious setup.cfg file.

* Wed Sep 23 2009 Lev Givon <lev@mandriva.org> 0.99.1-1mdv2010.0
+ Revision: 447593
- Update to 0.99.1.

* Mon Aug 10 2009 Lev Givon <lev@mandriva.org> 0.99.0-2mdv2010.0
+ Revision: 414467
- Build docs as html.

* Sat Aug 08 2009 Frederik Himpe <fhimpe@mandriva.org> 0.99.0-1mdv2010.0
+ Revision: 411742
- Update to new version 0.99.0
- Remove literal patch: not needed anymore

* Tue May 19 2009 Paulo Andrade <pcpa@mandriva.com.br> 0.98.5.3-2mdv2010.0
+ Revision: 377417
- Rebuild without dependency on python-enthought-traits.

* Mon Feb 09 2009 Lev Givon <lev@mandriva.org> 0.98.5.3-1mdv2009.1
+ Revision: 338955
- Update to 0.98.5.3.

* Wed Dec 31 2008 Adam Williamson <awilliamson@mandriva.org> 0.98.5.2-2mdv2009.1
+ Revision: 321619
- rebuild for python 2.6
- clean up python requires
- add literal.patch (fix a string literal error)

* Fri Dec 19 2008 Lev Givon <lev@mandriva.org> 0.98.5.2-1mdv2009.1
+ Revision: 316008
- Update to 0.98.5.2.

* Fri Dec 12 2008 Lev Givon <lev@mandriva.org> 0.98.5-1mdv2009.1
+ Revision: 313694
- Update to 0.98.5.

* Wed Dec 10 2008 Lev Givon <lev@mandriva.org> 0.98.4-1mdv2009.1
+ Revision: 312592
- Update to 0.98.4.

* Sat Dec 06 2008 Adam Williamson <awilliamson@mandriva.org> 0.98.3-3mdv2009.1
+ Revision: 311038
- rebuild for new tcl
- small cleanup

* Fri Oct 31 2008 Lev Givon <lev@mandriva.org> 0.98.3-2mdv2009.1
+ Revision: 298971
- Remove python-enthought-traits-ui dependency
  (no longer needed after upgrade to traits 3).

* Thu Aug 07 2008 Lev Givon <lev@mandriva.org> 0.98.3-1mdv2009.0
+ Revision: 266422
- Update to 0.98.3.
  Build user manual directly from source.

* Thu Jul 17 2008 Lev Givon <lev@mandriva.org> 0.98.2-3mdv2009.0
+ Revision: 237778
- Add traits dependencies.

* Fri Jul 11 2008 Lev Givon <lev@mandriva.org> 0.98.2-2mdv2009.0
+ Revision: 233825
- Add python-pytz and python-dateutil dependencies.
- Update to 0.98.2.
- Update to 0.98.1.

* Sun Jun 01 2008 Lev Givon <lev@mandriva.org> 0.98.0-1mdv2009.0
+ Revision: 214132
- Update to 0.98.0.

* Wed Mar 19 2008 Lev Givon <lev@mandriva.org> 0.91.2-2mdv2008.1
+ Revision: 188792
- Add python-config dependency (39041).

* Wed Jan 09 2008 Lev Givon <lev@mandriva.org> 0.91.2-1mdv2008.1
+ Revision: 147007
- Update to 0.91.2.

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Thu Dec 06 2007 Lev Givon <lev@mandriva.org> 0.91.1-2mdv2008.1
+ Revision: 116031
- Replace my patch with the one from the matplotlib developers.

* Wed Dec 05 2007 Lev Givon <lev@mandriva.org> 0.91.1-1mdv2008.1
+ Revision: 115740
- Update to 0.91.1.
  Add patch to fix matplotlib bug 1845057.

* Wed Nov 21 2007 Lev Givon <lev@mandriva.org> 0.90.1-2mdv2008.1
+ Revision: 111043
- Clean up build requirements.

* Sun Jun 03 2007 Lev Givon <lev@mandriva.org> 0.90.1-1mdv2008.0
+ Revision: 34938
- Update to 0.90.1.
  Tweak build deps.


* Mon Mar 19 2007 Lev Givon <lev@mandriva.org> 0.90.0-2mdv2007.1
+ Revision: 146366
- Add user manual.

* Wed Feb 07 2007 Lev Givon <lev@mandriva.org> 0.90.0-1mdv2007.1
+ Revision: 117115
- Update to 0.90.0.

* Fri Jan 26 2007 Lev Givon <lev@mandriva.org> 0.87.7-3mdv2007.1
+ Revision: 114197
- Improve dependency information.

* Sun Dec 10 2006 Lev Givon <lev@mandriva.org> 0.87.7-2mdv2007.1
+ Revision: 94418
- Bump release to force rebuild with Python 2.5.

* Wed Nov 01 2006 Lev Givon <lev@mandriva.org> 0.87.7-1mdv2007.1
+ Revision: 75080
- Update to 0.87.7.

* Wed Nov 01 2006 Lev Givon <lev@mandriva.org> 0.87.6-2mdv2007.1
+ Revision: 75024
- Raise release number to placate build system.
- Update to 0.87.6.
- Import python-matplotlib

* Mon Jul 17 2006 Lev Givon <lev@mandriva.org> 0.87.4-2mdk
- Rebuild against python-numpy 1.0b1.

* Mon Jul 17 2006 Lev Givon <lev@mandriva.org> 0.87.4-1mdk
- Update version.

* Tue Jun 13 2006 Lev Givon <lev@mandriva.org> 0.87.3-1mdk
- Update version.

* Tue Mar 28 2006 Lev Givon <lev@mandriva.org> 0.87.2-3mdk
- add mpl3d module

* Fri Mar 24 2006 Lev Givon <lev@mandriva.org> 0.87.2-2mdk
- make buildreqs backward compatible

* Sun Mar 19 2006 Lev Givon <lev@mandriva.org> 0.87.2-1mdk
- upgrade to 0.87.2
- add numpy dependency

* Fri Feb 03 2006 Lev Givon <lev@mandriva.org> 0.86.2-1mdk
- upgrade to 0.86.2
- fix installation datapath

* Tue Jan 03 2006 Oden Eriksson <oeriksson@mandriva.com> 0.85-1mdk
- 0.85
- fix deps

* Mon Aug 01 2005 Lev Givon <lev@mandriva.org> 0.83.2-1mdk
- upgrade to 0.83.2

* Wed Jul 20 2005 Lenny Cartier <lenny@mandriva.com> 0.82-5mdk
- add examples (Lev Givon)
- add Python license to satisfy rpmlint

* Fri Jul 15 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.82-4mdk
- fix buildrequires

* Wed Jul 13 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.82-3mdk
- fix requres

* Fri Jun 17 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.82-2mdk
- blah, fix buildrequires

* Fri Jun 17 2005 Per Øyvind Karlsen <pkarlsen@mandriva.com> 0.82-1mdk
- inital release

